What is TOPSIS? Technique for Order Preference by Similarity to Ideal Solution (TOPSIS) originated in the 1980s as a multi-criteria decision making method. TOPSIS chooses the altenrative of shortest Euclidean distance from the idael solution, and fartherst distance from the negative-ideal solution. More details at wikipedia. The TOPSIS algorithm is succintly explained in this paper comparing TOPSIS and VIKOR methods.

Just install my package using pip install topsis_ashwin , import it and use the class topsis's evaluate function to get the result.

The code is included inside too as topsis_code.py